@@ -1,5 +1,5 @@
 var searchData=
 [
   ['rnifti_3a_20fast_20r_20and_20c_2b_2b_20access_20to_20nifti_20images',['RNifti: Fast R and C++ Access to NIfTI Images',['../index.html',1,'']]],
-  ['rescale',['rescale',['../class_nifti_image.html#a351a011115b703a1f9748e491cd96ef7',1,'NiftiImage']]]
+  ['rescale',['rescale',['../class_r_nifti_1_1_nifti_image.html#abcf3f45286d37515de42720d75a6f82b',1,'RNifti::NiftiImage']]]
 ];
