@@ -9,9 +9,11 @@
  * @mainpage RNifti: Fast R and C++ Access to NIfTI Images
  * A more extensive overview of the \c RNifti package, and its usage from R, is provided on the
  * package's GitHub page at \c https://github.com/jonclayden/RNifti. The primary role of these
- * pages is to document the \ref NiftiImage C++ class for package developers linking to \c RNifti.
+ * pages is to document the \ref RNifti::NiftiImage C++ class for package developers linking to
+ * \c RNifti.
 **/
 
+namespace RNifti {
 
 /**
  * Thin wrapper around a C-style \c nifti_image struct that allows C++-style destruction
@@ -1386,4 +1388,6 @@ inline Rcpp::RObject NiftiImage::headerToList () const
     return result;
 }
 
+} // namespace
+
 #endif
